from setuptools import setup, find_packages

setup(
	name="ansible-base",
	version="0.0.1a2",
	packages=find_packages("lib"),
	author="Ansible Project",
	author_email="info@ansible.com",
	url="https://github.com/ansible/ansible/"
)
